@@ -95,11 +95,7 @@ def passport_transforms(passport_data, space_data):
     passport_data['Comparison Date'] = pd.to_datetime(passport_data['Comparison Date']).dt.strftime('%Y-%m-%d %H:00:00')
 
     ### YEAR
-    passport_data['Year'] = None
-    passport_data.loc[passport_data['Session Start'].dt.year == datetime.now().year, 'Year'] = 'This Year'
-    passport_data.loc[(passport_data['Session Start'].dt.year < datetime.now().year) &
-                      (passport_data['Session Start'].dt.year > datetime.now().year - 2), 'Year'] = 'Last Year'
-    passport_data.loc[passport_data['Session Start'].dt.year <= datetime.now().year - 2, 'Year'] = pd.to_numeric(datetime.now().year - passport_data['Session Start'].dt.year).astype('str') + ' Years Ago'
+    passport_data['Year'] = passport_data['Session Start'].dt.year.astype(str)
 
     ### DURATION IN MINUTES
     passport_data = passport_data.rename(columns={'parkingdurationinmins': 'Duration in Minutes'})
